@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.088-2-g23c2efc
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.089-6-gacd0495
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.089';
+our $VERSION = '0.090';
 
 use Moose;
 with
@@ -66,7 +66,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    uniq $self->$orig(@_), qw(LICENSE CONTRIBUTING);
+    uniq $self->$orig(@_), qw(LICENSE CONTRIBUTING Changes);
 };
 
 has changes_version_columns => (
@@ -103,7 +103,7 @@ my %network_plugins;
 my $has_bash = can_run('bash');
 
 # files that might be in the repository that should never be gathered
-my @never_ship = qw(Makefile.PL README.md README.pod META.json cpanfile TODO);
+my @never_gather = qw(Makefile.PL README.md README.pod META.json cpanfile TODO CONTRIBUTING LICENSE);
 
 around BUILDARGS => sub
 {
@@ -153,7 +153,7 @@ sub configure
 
         # Gather Files
         [ 'Git::GatherDir'      => { ':version' => '2.016', do {
-                my @filenames = grep { -e } uniq @never_ship, $self->copy_files_from_release;
+                my @filenames = grep { -e } @never_gather;
                 @filenames ? ( exclude_filename => \@filenames ) : ()
             },
         } ],
@@ -192,7 +192,6 @@ sub configure
                 post_code_replacer => 'replace_with_nothing',
             }
         ],
-        [ 'NextRelease'         => { ':version' => '4.300018', time_zone => 'UTC', format => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
         [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
 
         # MetaData
@@ -260,12 +259,13 @@ sub configure
         ( -e 'README.md' ?
             [ 'Run::AfterRelease' => 'remove old READMEs' => { ':version' => '0.024', eval => q!unlink 'README.md'! } ]
             : ()),
-        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'Changes', 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
-        [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
+        [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
+        [ 'Git::Tag'            => { tag_format => 'v%v', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
 
         [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004' } ],
-        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty_match => '^lib/', commit_msg => 'increment $VERSION after release' } ],
+        [ 'NextRelease'         => { ':version' => '5.033', time_zone => 'UTC', format => '%-' . ($self->changes_version_columns - 2) . 'v  %{yyyy-MM-dd HH:mm:ss\'Z\'}d%{ (TRIAL RELEASE)}T' } ],
+        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty => [ 'Changes' ], allow_dirty_match => '^lib/', commit_msg => 'increment $VERSION after release' } ],
         'Git::Push',
     );
 
@@ -366,7 +366,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.089
+version 0.090
 
 =head1 SYNOPSIS
 
@@ -478,10 +478,6 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     replacer = replace_with_comment
     post_code_replacer = replace_with_nothing
 
-    [NextRelease]
-    :version = 4.300018
-    time_zone = UTC
-    format = %-8v  %{uyyy-MM-dd HH:mm:ss'Z'}d%{ (TRIAL RELEASE)}T
     [ReadmeAnyFromPod]
     :version = 0.142180
     type = pod
@@ -603,6 +599,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [CopyFilesFromRelease]
     filename = LICENSE
     filename = CONTRIBUTING
+    filename = Changes
 
     [Run::AfterRelease / remove old READMEs]
     :version = 0.024
@@ -619,7 +616,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     commit_msg = %N-%v%t%n%n%c
 
     [Git::Tag]
-    tag_format = v%v%t
+    tag_format = v%v
     tag_message = v%v%t
 
     [GitHub::Update]    ; (if server = 'github' or omitted)
@@ -628,8 +625,13 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     [BumpVersionAfterRelease::Transitional]
     :version = 0.004
+    [NextRelease]
+    :version = 5.033
+    time_zone = UTC
+    format = %-8v  %{uyyy-MM-dd HH:mm:ss'Z'}d%{ (TRIAL RELEASE)}T
     [Git::Commit / post-release commit]
     :version = 2.020
+    allow_dirty = Changes
     allow_dirty_match = ^lib
     commit_msg = increment $VERSION after release
     [Git::Push]
